;; Generated package description from gnosis.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "gnosis" "0.10.3" "Knowledge System" '((emacs "29.1") (compat "29.1.4.2")) :commit "e830171c4bcbcbc0b1d466ffdbec179e32e9688e" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("extensions") :url "https://thanosapollo.org/projects/gnosis")
